@@ -335,6 +335,22 @@ def addHuntGroupAgent(accessToken, locationId, huntGroupId, jsonData, orgId):
     results = APIRESPONSE.text
     return results
 
+def listCallerId(accessToken, userId, orgId):
+    APIURI = "https://webexapis.com/v1/people/"
+    APIHEADER = {'Authorization': 'Bearer ' + accessToken, 'Content-Type' : 'application/json', 'Accept' : '*/*'}
+    APIURI = APIURI + userId + "/features/callerId" + "?orgId=" + orgId
+    APIRESPONSE = requests.get(APIURI, headers=APIHEADER) 
+    callerId = APIRESPONSE.json()
+    return callerId
+
+def updateCallerId(accessToken, userId, orgId, jsondata):
+    APIURI = "https://webexapis.com/v1/people/"
+    APIHEADER = {'Authorization': 'Bearer ' + accessToken, 'Content-Type' : 'application/json', 'Accept' : '*/*'}
+    APIURI = APIURI + userId + "/features/callerId" + "?orgId=" + orgId
+
+    APIRESPONSE = requests.put(APIURI, headers=APIHEADER, data = json.dumps(jsondata))
+    return APIRESPONSE.text
+
 #Functions below this point are in progress
 
 # def getAutoAttendants(accessToken, orgId):
